@@ -1,5 +1,8 @@
-from typing import Optional
+from typing import Optional, Union
 from datetime import datetime
+import pandas as pd  # type: ignore
+from cfinterface.adapters.field.repository import Repository
+from cfinterface.adapters.field.textualrepository import TextualRepository
 
 from cfinterface.components.field import Field
 
@@ -14,16 +17,20 @@ class DatetimeField(Field):
     def __init__(
         self,
         size: int = 16,
-        starting_column: int = 0,
+        starting_position: int = 0,
         format: str = "%Y/%m/%d",
         value: Optional[datetime] = None,
+        interface: Repository = TextualRepository(),
     ) -> None:
-        super().__init__(size, starting_column, value)
+        super().__init__(size, starting_position, value, interface)
         self.__format = format
 
     # Override
-    def read(self, line: str) -> Optional[datetime]:
-        linevalue = line[self._starting_column : self._ending_column].strip()
+    def read(self, line: Union[str, bytes]) -> Optional[datetime]:
+        readline = self._interface.read(line)
+        linevalue = readline[
+            self._starting_position : self._ending_position
+        ].strip()
         try:
             self._value = datetime.strptime(linevalue, self.__format)
         except ValueError:
@@ -31,16 +38,12 @@ class DatetimeField(Field):
         return self._value
 
     # Override
-    def write(self, line: str) -> str:
-        if len(line) < self._ending_column:
-            line = line.ljust(self._ending_column)
-        value = ""
-        if self.value is not None:
+    def write(self, line: Union[str, bytes]) -> str:
+        value = "".ljust(self._size)
+        if self.value is not None and not pd.isnull(self.value):
             value = self.value.strftime(self.__format)
-        return (
-            line[: self._starting_column]
-            + value.rjust(self._size)
-            + line[self._ending_column :]
+        return self._interface.write(
+            value, line, self._starting_position, self._ending_position
         )
 
     @property
