@@ -23,7 +23,7 @@ class BlockWriting:
         for b in self.__data:
             b.write(file)
 
-    def write(self, filename: str, directory: str):
+    def write(self, filename: str, directory: str, encoding: str):
         """
         Writes a file with a given name in a given directory with
         the data from the BlockData structure.
@@ -32,9 +32,11 @@ class BlockWriting:
         :type filename: str
         :param directory: The directory where the file will be
         :type directory: str
+        :param encoding: The encoding for reading the file
+        :type encoding: str
         """
         filepath = join(directory, filename)
-        with open(filepath, "w") as fp:
+        with open(filepath, "w", encoding=encoding) as fp:
             return self.__write_file(fp)
 
     @property
